package org.bdware.mockjava;

import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonPrimitive;
import org.bdware.mockjava.generator.IntegerGenerator;

public class MockGenerator extends JsonVisitor {
    public static MockGenerator instance = new MockGenerator();

    @Override
    public JsonVisitor visitJsonArray(JsonArray array) {
        JsonArray ret = new JsonArray();
        if (array.size() > 0) {
            visit(array.get(0));
            ret.add(result);
        }
        result = ret;
        return this;
    }

    @Override
    public JsonVisitor visitPrimitive(JsonPrimitive primitive) {
        if (!primitive.isString()) {
            result = primitive.deepCopy();
        }
        ValueGenerator generator = lookupGenerator(primitive.getAsString());
        result = generator.generate(null, primitive);
        return this;
    }

    private ValueGenerator lookupGenerator(final String str) {
        if (!str.startsWith("@")) {
            return new ValueGenerator() {
                @Override
                public JsonElement generate(String preField, JsonElement previous) {
                    return new JsonPrimitive(str);
                }
            };
        }
        String[] args = null;
        int from = str.indexOf("(");
        if (from != -1) {
            int to = str.indexOf(")");
            String subStr = str.substring(from + 1, to);
            args = subStr.split(",");
        }
        return IntegerGenerator.create(args);
    }
}
